
import 'dart:async';

import 'package:flutter/services.dart';

class AppconsentClassic {
  static const MethodChannel _channel = MethodChannel('appconsent_classic');

  /// Setup the AppConsent SDK
  static Future<void> setup(
          String appKey, bool forceApplyGDPR, bool forceATT) async =>
      await _channel.invokeMethod("setup", {
        "appKey": appKey,
        "forceApplyGDPR": forceApplyGDPR,
        "forceATT": forceATT
      });

  /// Present the Notice if needed
  static Future<void> presentNotice(bool force) async {
    await _channel.invokeMethod("presentNotice", {"force": force});
  }

  /// Clear user consent, this only clears local consent in UserDefaults, not on server
  static Future<void> clearConsent() async {
    await _channel.invokeMethod('clearConsent');
  }

  static Future<bool> get checkForUpdate async {
    final bool result = await _channel.invokeMethod('checkForUpdate');
    return result;
  }

  static Future<bool> get isGDPRCountry async {
    final bool result = await _channel.invokeMethod('isGDPRCountry');
    return result;
  }

  /// Check if consent was given
  static Future<bool> get consentGiven async {
    final bool result = await _channel.invokeMethod('consentGiven');
    return result;
  }

  //iOS only
  static Future<bool> get appTrackingIsAvailable async {
    final bool result = await _channel.invokeMethod('appTrackingIsAvailable');
    return result;
  }

  static Future<bool> get appTrackingAuthorizationGiven async {
    final bool result =
        await _channel.invokeMethod('appTrackingAuthorizationGiven');
    return result;
  }

  static Future<int> get appTrackingAuthorizationStatus async {
    final int result =
        await _channel.invokeMethod('appTrackingAuthorizationStatus');
    return result;
  }
}
